@@ -1,14 +1,14 @@
 import os
-from urllib.parse import urlparse
 
-import cirrocumulus.data_processing as data_processing
-from cirrocumulus.envir import CIRRO_SERVE, CIRRO_FOOTER, CIRRO_UPLOAD
 from flask import Blueprint, Response, request, stream_with_context, current_app
 
+import cirrocumulus.data_processing as data_processing
 from .dataset_api import DatasetAPI
+from .envir import CIRRO_SERVE, CIRRO_FOOTER, CIRRO_UPLOAD, CIRRO_BRAND
+from .file_system_adapter import get_scheme
 from .invalid_usage import InvalidUsage
 from .job_api import submit_job
-from .util import *
+from .util import to_json
 
 blueprint = Blueprint('blueprint', __name__)
 
@@ -33,10 +33,13 @@ def handle_server():
     # no login required
     server = get_database().server()
     server['clientId'] = get_auth().client_id
-    footer_path = os.environ.get(CIRRO_FOOTER)
-    if footer_path is not None:
-        with open(footer_path, 'rt') as f:
+    if os.environ.get(CIRRO_FOOTER) is not None:
+        with open(os.environ.get(CIRRO_FOOTER), 'rt') as f:
             server['footer'] = f.read()
+    if os.environ.get(CIRRO_BRAND) is not None:
+        with open(os.environ.get(CIRRO_BRAND), 'rt') as f:
+            server['brand'] = f.read()
+    # server['brand'] = os.environ.get(CIRRO_BRAND)
     server['jobs'] = os.environ.get('GAE_APPLICATION') is None
     server['upload'] = os.environ.get(CIRRO_UPLOAD) is not None
     return to_json(server)
@@ -195,18 +198,13 @@ def get_file_path(file, dataset_url):
     # when serving dataset, image must be relative to dataset directory
     if os.environ.get(CIRRO_SERVE) == 'true':
         _, ext = os.path.splitext(dataset_url)
-        if ext != '':
-            url = os.path.dirname(dataset_url)
         if file[0] == '/' or file.find('..') != -1:
             raise ValueError('Incorrect path')
         file_path = os.path.join(dataset_url, file)
     else:
         file_path = file
-        pr = urlparse(file_path)
-        if (pr.scheme == '' or pr.scheme == 'file') and not os.path.exists(file_path):
-            _, ext = os.path.splitext(dataset_url)
-            if ext != '':
-                url = os.path.dirname(dataset_url)
+        scheme = get_scheme(file_path)
+        if scheme == 'file' and not os.path.exists(file_path):
             file_path = os.path.join(dataset_url, file)
     return file_path
 
@@ -307,9 +305,37 @@ def upload_file(file):
     from werkzeug.utils import secure_filename
     filename = secure_filename(file.filename)
     dest = os.path.join(os.environ.get(CIRRO_UPLOAD), filename)
-    fs = dataset_api.fs_adapter.get_fs(dest).open(dest, mode='wb')
-    file.save(fs)
-    fs.close()
+    dest_fs = dataset_api.fs_adapter.get_fs(dest).open(dest, mode='wb')
+    file.save(dest_fs)
+    dest_fs.close()
+    return dest
+
+
+def copy_url(url):
+    import fsspec
+    from werkzeug.utils import secure_filename
+    upload = os.environ.get(CIRRO_UPLOAD)
+
+    if url.endswith('/'):  # don't copy directories
+        return url
+    from urllib.parse import urlparse
+    if urlparse(upload).netloc == urlparse(url).netloc:  # don't copy if already in the same bucket
+        return url
+    src_scheme = get_scheme(url)
+    src_fs = fsspec.filesystem(src_scheme)
+    filename = secure_filename(os.path.basename(url))
+    dest = os.path.join(upload, filename)
+    dest_scheme = get_scheme(dest)
+    dest_fs = fsspec.filesystem(dest_scheme)
+    out = dest_fs.open(dest, 'wb')
+    n = 1024 * 1024
+    with src_fs.open(url, mode='rb') as r:
+        while True:
+            b = r.read(n)
+            if not b:
+                break
+            out.write(b)
+    out.close()
     return dest
 
 
@@ -335,6 +361,9 @@ def handle_dataset():
         if request.method == 'POST' and dataset_name == '':  # new
             return 'Must supply dataset name', 400
 
+        if url is not None and os.environ.get(CIRRO_UPLOAD) is not None:
+            url = copy_url(url)
+
         if file is not None:
             if os.environ.get(CIRRO_UPLOAD) is None:
                 return 'Upload not supported', 400
