@@ -1,5 +1,3 @@
-from natsort.natsort import natsorted
-
 from cirrocumulus.simple_data import SimpleData
 
 
@@ -26,15 +24,11 @@ class FeatureAggregator:
 
     def execute(self, df):
         result = {}
-
         for column in self.dimensions:
             df_counts = df.agg({column: lambda x: x.value_counts(sort=False)})
-            sorted_categories = natsorted(df_counts.index)
-            df_counts = df_counts.iloc[df_counts.index.get_indexer_for(sorted_categories)]
-            dimension_summary = {'categories': df_counts.index.to_list(),
-                                 'counts': df_counts[column].to_list()}
+            dimension_summary = {'categories': df_counts.index,
+                                 'counts': df_counts[column]}
             result[column] = dimension_summary
-
         if len(self.var_measures) > 0:
             FeatureAggregator.add_to_result(SimpleData.X_stats(df, self.var_measures), result)
         if len(self.obs_measures) > 0:
