@@ -82,10 +82,8 @@ const styles = (theme) => {
 
 class App extends PureComponent {
 
-
     constructor(props) {
         super(props);
-        this.state = {tab: 'embedding'};
         this.tooltipElementRef = React.createRef();
         this.galleryRef = React.createRef();
     }
@@ -158,6 +156,11 @@ class App extends PureComponent {
                                 hidden={tab !== 'distribution'}
                             >
                                 <DistributionPlots setTooltip={this.setTooltip}/>
+                            </div>
+                            <div
+                                role="tabpanel"
+                                hidden={tab !== 'composition'}
+                            >
                                 <CompositionPlots/>
                             </div>
                             <div
