@@ -42,7 +42,7 @@ import {
     DEFAULT_SHOW_FOG,
     DEFAULT_UNSELECTED_MARKER_OPACITY
 } from "./reducers";
-import {FEATURE_TYPE, reactMarkdownOptions} from './util';
+import {copyToClipboard, FEATURE_TYPE, REACT_MD_OVERRIDES} from './util';
 
 
 const styles = theme => ({
@@ -260,41 +260,11 @@ class AppHeader extends React.PureComponent {
     };
 
     copyLink = (event) => {
-
         let linkText = window.location.protocol + '//' + window.location.host + window.location.pathname;
-        linkText += '?q=' + encodeURIComponent(JSON.stringify(this.getLinkJson()));
-        const container = document.activeElement;
-        const fakeElem = document.createElement('textarea');
-        const isRTL = document.documentElement.getAttribute('dir') == 'rtl';
-        fakeElem.style.fontSize = '12pt';
-        fakeElem.style.border = '0';
-        fakeElem.style.padding = '0';
-        fakeElem.style.margin = '0';
-        // Move element out of screen horizontally
-        fakeElem.style.position = 'absolute';
-        fakeElem.style[isRTL ? 'right' : 'left'] = '-9999px';
-        fakeElem.setAttribute('readonly', '');
-        // Move element to the same position vertically
-        let yPosition = window.pageYOffset || document.documentElement.scrollTop;
-        fakeElem.style.top = yPosition + 'px';
-        fakeElem.value = linkText;
-        container.appendChild(fakeElem);
-
-        fakeElem.select();
-        fakeElem.setSelectionRange(0, fakeElem.value.length);
-
-        document.execCommand('copy');
-
-        const fakeHandlerCallback = (event) => {
-            document.activeElement.blur();
-            window.getSelection().removeAllRanges();
-            container.removeChild(fakeElem);
-            container.removeEventListener('click', fakeHandlerCallback);
-        };
+        linkText += '#q=' + encodeURIComponent(JSON.stringify(this.getLinkJson()));
+        copyToClipboard(linkText);
         this.props.setMessage('Link copied');
-        container.addEventListener('click', fakeHandlerCallback);
         this.setState({moreMenuOpen: false});
-
     };
 
 
@@ -385,7 +355,7 @@ class AppHeader extends React.PureComponent {
                                 Title: {dataset.title}
                             </Typography>}
                             {dataset.description &&
-                            <>Description: <ReactMarkdown options={reactMarkdownOptions}
+                            <>Description: <ReactMarkdown options={{overrides: REACT_MD_OVERRIDES}}
                                                           children={dataset.description}/></>}
                             {!process.env.REACT_APP_STATIC === 'true' && <Typography className={classes.typography}>
                                 URL: {dataset.url}
@@ -434,11 +404,25 @@ class AppHeader extends React.PureComponent {
 
 
                     <div style={{marginLeft: 'auto', whiteSpace: 'nowrap', overflow: 'hidden'}}>
-                        {serverInfo.brand && <Typography variant="h5"
-                                                         style={{
-                                                             display: 'inline-block',
-                                                             paddingRight: 6
-                                                         }}>{serverInfo.brand}</Typography>}
+                        {/*{serverInfo.brand && <Typography variant="h5"*/}
+                        {/*                                 style={{*/}
+                        {/*                                     display: 'inline-block',*/}
+                        {/*                                     paddingRight: 6*/}
+                        {/*                                 }}>{serverInfo.brand}</Typography>}*/}
+
+                        {serverInfo.brand &&
+                        <ReactMarkdown options={{
+                            overrides: REACT_MD_OVERRIDES, wrapper: 'span', createElement: (type, props, children) => {
+                                props.display = 'inline';
+                                props.gutterBottom = false;
+                                const elem = React.createElement(type, props, children);
+                                return elem;
+                            }
+                        }}
+
+                                       children={serverInfo.brand}/>}
+
+
                         {!loadingApp.loading && !isSignedOut && <DatasetSelector onChange={this.handleDataset}/>}
                         {showMoreMenu && <Tooltip title={'More'}>
                             <IconButton aria-label="Menu" aria-haspopup="true"
