@@ -1,6 +1,5 @@
 import {Tooltip, Typography} from '@material-ui/core';
 import Button from '@material-ui/core/Button';
-import CircularProgress from '@material-ui/core/CircularProgress';
 import Dialog from '@material-ui/core/Dialog';
 import DialogContent from '@material-ui/core/DialogContent';
 import IconButton from '@material-ui/core/IconButton';
@@ -19,7 +18,7 @@ import ReactMarkdown from 'markdown-to-jsx';
 import React from 'react';
 import {connect} from 'react-redux';
 import {setDialog} from './actions';
-import {NATSORT, reactMarkdownOptions} from './util';
+import {NATSORT, REACT_MD_OVERRIDES} from './util';
 
 export class DatasetSelector extends React.PureComponent {
 
@@ -105,14 +104,11 @@ export class DatasetSelector extends React.PureComponent {
                     }}
                 >
                     <div style={{width: 500}}>
-                        {selectedDataset == null &&
-                        <div><CircularProgress size={20}/> Loading...</div>}
-
                         {!hasMoreInfo && <div>No description available</div>}
-
                         {selectedDataset && selectedDataset.title && <div>{selectedDataset.title}</div>}
                         {selectedDataset && selectedDataset.description &&
-                        <ReactMarkdown options={reactMarkdownOptions} children={selectedDataset.description}/>}
+                        <ReactMarkdown options={{overrides: REACT_MD_OVERRIDES}}
+                                       children={selectedDataset.description}/>}
                     </div>
                 </Popover>
                 {selectedId == null && <Button variant="contained" onClick={this.handleClick}
