@@ -3,7 +3,6 @@ import Box from '@material-ui/core/Box';
 import CircularProgress from '@material-ui/core/CircularProgress';
 import Typography from '@material-ui/core/Typography';
 import React from 'react';
-import {getEmbeddingKey} from './actions';
 import {drawEmbeddingImage, getSpotRadius} from './ImageChart';
 import {drawLabels, getVisualizer} from './ScatterChartThree';
 import {
@@ -22,33 +21,28 @@ class GalleryImage extends React.PureComponent {
         this.elementRef = React.createRef();
     }
 
-
     draw() {
         const {
-            obsCat,
             cachedData,
-            scatterPlot,
-            chartSize,
             categoricalNames,
-            containerElement,
-            traceInfo,
-            markerOpacity,
-            unselectedMarkerOpacity,
-            selection,
             chartOptions,
-            pointSize
+            chartSize,
+            containerElement,
+            markerOpacity,
+            obsCat,
+            pointSize,
+            scatterPlot,
+            selection,
+            traceInfo,
+            unselectedMarkerOpacity,
         } = this.props;
-        const embedding = traceInfo.embedding;
-        const fullName = getEmbeddingKey(embedding);
-        const chartSelection = selection != null && selection.chart != null ? selection.chart[fullName] : null;
-        const userPoints = chartSelection ? chartSelection.userPoints : new Set();
         if (traceInfo.type === 'scatter') {
             let spriteVisualizer = getVisualizer(scatterPlot, POINT_VISUALIZER_ID);
             spriteVisualizer.zoomFactor = this.zoomFactor;
-            updateScatterChart(scatterPlot, traceInfo, userPoints, markerOpacity, unselectedMarkerOpacity, pointSize,
+            updateScatterChart(scatterPlot, traceInfo, selection, markerOpacity, unselectedMarkerOpacity, pointSize,
                 categoricalNames, chartOptions, obsCat, cachedData);
             const canvas = containerElement.querySelector('canvas');
-            const showLabels = obsCat.length > 0 && chartSize >= 600;
+            const showLabels = obsCat.length > 0 && chartOptions.showGalleryLabels;
             let overlayUrl = null;
             if (showLabels) {
                 const labelsPositions = getCategoryLabelsPositions(traceInfo.embedding, obsCat, cachedData);
@@ -81,7 +75,7 @@ class GalleryImage extends React.PureComponent {
                 drawEmbeddingImage(context, {
                     width: chartSize,
                     height: chartSize
-                }, traceInfo, userPoints, markerOpacity, unselectedMarkerOpacity, chartOptions, categoricalNames, obsCat, cachedData, getSpotRadius(traceInfo, pointSize));
+                }, traceInfo, selection, markerOpacity, unselectedMarkerOpacity, chartOptions, categoricalNames, obsCat, cachedData, getSpotRadius(traceInfo, pointSize));
                 this.setState({url: canvas.toDataURL(), overlayUrl: null, loading: false, element: null});
                 canvas = null;
             }
@@ -145,26 +139,21 @@ class GalleryImage extends React.PureComponent {
                     height: this.props.chartSize,
                     cursor: 'pointer'
                 }}>
-
                     <Tooltip title={"Embedding: " + this.props.traceInfo.embedding.name}>
-                        <Typography color="textPrimary" component={"h4"}
+                        <Typography color="textPrimary" variant={"caption"}
                                     onClick={this.onSelect}
                                     style={{
-                                        marginTop: '3.2px',
+                                        marginTop: 3.2,
                                         position: 'absolute',
                                         right: 4,
                                         zIndex: 1000
                                     }}>{name}</Typography>
                     </Tooltip>
-
-
                     {this.state.loading && <CircularProgress
                         style={{position: 'absolute', left: this.props.chartSize / 2, top: this.props.chartSize / 2}}
                         size={20}/>}
-
                     <div onClick={this.onSelect} ref={this.elementRef}
                          style={{position: 'absolute', left: 0, top: 0}}></div>
-
                     {this.state.url &&
                     <div style={{position: 'absolute', left: 0, top: 0}}>
                         <img alt="" src={this.state.url}
