@@ -1,5 +1,4 @@
 import {DialogActions, DialogContentText, InputLabel, Switch, Typography} from '@material-ui/core';
-
 import Box from '@material-ui/core/Box';
 import Button from '@material-ui/core/Button';
 import ButtonGroup from '@material-ui/core/ButtonGroup';
@@ -14,6 +13,7 @@ import FormHelperText from '@material-ui/core/FormHelperText';
 import Grid from '@material-ui/core/Grid';
 import IconButton from '@material-ui/core/IconButton';
 import Input from '@material-ui/core/Input';
+import Link from '@material-ui/core/Link';
 import List from '@material-ui/core/List';
 import ListItem from '@material-ui/core/ListItem';
 import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction';
@@ -27,6 +27,7 @@ import TextField from '@material-ui/core/TextField';
 import Tooltip from '@material-ui/core/Tooltip';
 import ArrowDropDownIcon from '@material-ui/icons/ArrowDropDown';
 import CloudDownloadIcon from '@material-ui/icons/CloudDownload';
+import CompareIcon from '@material-ui/icons/Compare';
 import DeleteIcon from '@material-ui/icons/Delete';
 import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
 import FontDownloadRoundedIcon from '@material-ui/icons/FontDownloadRounded';
@@ -72,7 +73,15 @@ import AutocompleteVirtualized from './AutocompleteVirtualized';
 import {EditableColorScheme} from './EditableColorScheme';
 import {intFormat} from './formatters';
 import JobResultOptions from './JobResultOptions';
-import {FEATURE_TYPE, getFeatureSets, NATSORT, splitSearchTokens, TRACE_TYPE_META_IMAGE,} from './util';
+import NumberIcon from './NumberIcon';
+import {
+    copyToClipboard,
+    FEATURE_TYPE,
+    getFeatureSets,
+    NATSORT,
+    splitSearchTokens,
+    TRACE_TYPE_META_IMAGE,
+} from './util';
 
 const pointSizeOptions = [{value: 0.1, label: '10%'}, {value: 0.25, label: '25%'}, {value: 0.5, label: '50%'}, {
     value: 0.75,
@@ -98,7 +107,7 @@ const styles = theme => ({
     formControl: {
         display: 'block',
         minWidth: 200,
-        margin: theme.spacing(0, 1)
+        margin: theme.spacing(0, 1),
     },
     margin: {
         margin: theme.spacing(1, 1)
@@ -110,7 +119,7 @@ const styles = theme => ({
         '& hr': {
             margin: theme.spacing(0, 0.5),
         }
-    },
+    }
 });
 
 
@@ -124,10 +133,10 @@ const getAnnotationOptions = memoize(
             options.push({group: 'Categorical', text: item, id: item});
         });
         options.sort((item1, item2) => {
-            const c = NATSORT(item1.group, item2.group);
-            if (c !== 0) {
-                return c;
-            }
+            // const c = NATSORT(item1.group, item2.group);
+            // if (c !== 0) {
+            //     return c;
+            // }
             return NATSORT(item1.text, item2.text);
         });
         return options;
@@ -374,7 +383,7 @@ class SideBar extends React.PureComponent {
 
     onFeatureSetClick = (event, option) => {
         const id = option.id;
-        const target = event.target;
+        const target = event.target.closest(".MuiFormControl-root");
         let markers = this.props.markers;
 
         let featureSet = null;
@@ -465,6 +474,12 @@ class SideBar extends React.PureComponent {
     //     this.props.handleEmbeddings(embeddings.slice(0));
     // };
 
+    onFeatureCopy = (event) => {
+        event.preventDefault();
+        event.stopPropagation();
+        let searchTokens = this.props.searchTokens;
+        copyToClipboard(searchTokens.filter(token => token.type === FEATURE_TYPE.X).map(item => item.value).join('\n'));
+    };
     onFeatureClick = (event, option) => {
         event.stopPropagation();
         const value = option.text !== undefined ? option.text : option;
@@ -685,16 +700,15 @@ class SideBar extends React.PureComponent {
 
                 </Menu>
                 <AccordionStyled
-                    style={tab === 'embedding' || tab === 'distribution' ? null : {display: 'none'}}
+                    style={tab === 'embedding' || tab === 'distribution' || tab === 'composition' ? null : {display: 'none'}}
                     defaultExpanded>
-                    <AccordionSummaryStyled>
+                    <AccordionSummaryStyled style={{marginBottom: 4}}>
                         <Typography>View</Typography>
                     </AccordionSummaryStyled>
                     <AccordionDetailsStyled>
                         <div>
                             {tab === 'embedding' && embeddingOptions.length > 0 &&
                             <FormControl className={classes.formControl}>
-
                                 <AutocompleteVirtualized label={"Embeddings"}
                                                          options={embeddingOptions}
                                                          getChipTitle={(option) => {
@@ -713,17 +727,34 @@ class SideBar extends React.PureComponent {
                                                          options={featureOptions}
                                                          value={splitTokens.X}
                                                          onChange={this.onFeaturesChange}
-                                                         helperText={"Enter or paste list"}
+                                                         helperText={<>Enter or paste list <Link
+                                                             style={{
+                                                                 float: 'right',
+                                                                 display: splitTokens.X.length === 0 ? 'none' : ''
+                                                             }}
+                                                             onClick={this.onFeatureCopy}>Copy</Link></>}
+
                                 />
+
                             </FormControl>}
 
                             {annotationOptions.length > 0 && <FormControl className={classes.formControl}>
 
                                 <AutocompleteVirtualized label={"Cell Metadata"}
                                                          options={annotationOptions}
-                                                         value={splitTokens.obsCat.concat(splitTokens.obs)}
+                                                         value={searchTokens.filter(token => token.type === FEATURE_TYPE.OBS_CAT || token.type === FEATURE_TYPE.OBS).map(token => token.value)}
                                                          onChipClick={this.onFeatureClick}
-                                                         groupBy={true}
+                                                         groupBy={false}
+                                                         getOptionLabel={(option) => option.text}
+                                                         getOptionIcon={(option) => option.group === 'Categorical' ?
+                                                             <FontDownloadRoundedIcon style={{
+                                                                 marginRight: 2,
+                                                                 fontSize: '0.9rem'
+
+                                                             }}/> : <NumberIcon style={{
+                                                                 marginRight: 2,
+                                                                 fontSize: '0.9rem'
+                                                             }}/>}
                                                          getChipIcon={(option) => {
                                                              return splitTokens.obsCat.indexOf(option) !== -1 ?
                                                                  <FontDownloadRoundedIcon
@@ -863,7 +894,7 @@ class SideBar extends React.PureComponent {
                                     <Button size={"small"} disabled={selection.size === 0}
                                             onClick={event => this.onSetGroup(2)}>2</Button>
                                 </Tooltip>
-                                <Button size={"small"} variant="outlined"
+                                <Button startIcon={<CompareIcon/>} size={"small"} variant="outlined"
                                         disabled={selection.size === 0 || this.state.group1 == null || this.state.group2 == null}
                                         onClick={event => this.onSubmitJob('de')}>Go</Button>
                             </ButtonGroup>
@@ -1022,8 +1053,9 @@ class SideBar extends React.PureComponent {
                     </AccordionDetailsStyled>
                 </AccordionStyled>
                 {dynamic &&
-                <AccordionStyled style={tab === 'embedding' || tab === 'distribution' ? null : {display: 'none'}}
-                                 defaultExpanded>
+                <AccordionStyled
+                    style={tab === 'embedding' || tab === 'distribution' || tab === 'composition' ? null : {display: 'none'}}
+                    defaultExpanded>
                     <AccordionSummaryStyled expandIcon={<ExpandMoreIcon/>}>
                         <Typography>Saved Filters</Typography>
                     </AccordionSummaryStyled>
