@@ -142,6 +142,7 @@ export function computeDerivedStats(result, q, cachedData) {
         const measures = q.groupedStats.measures || [];
         const typeToMeasures = getTypeToMeasures(measures);
         if (dimensions.length > 0 && typeToMeasures.X.length > 0) {
+            // TODO, currently we only handle dimensions[0]
             result.distribution = groupedStats(getVectors(cachedData, dimensions[0]), getVectors(cachedData, typeToMeasures.X));
         }
     }
@@ -234,6 +235,7 @@ export function groupedStats(dimensions, varMeasures) {
                 categories: value.key,
                 feature: v.getName(),
                 mean: categoryStats.mean,
+                n: categoryVector.size(),
                 percentExpressed: 100 * (categoryStats.numExpressed / categoryVector.size()),
                 vector: categoryVector
             };
@@ -245,6 +247,22 @@ export function groupedStats(dimensions, varMeasures) {
 
 }
 
+export function toArray(v) {
+    const result = new Array(v.size());
+    for (let i = 0, n = v.size(); i < n; i++) {
+        result[i] = v.get(i);
+    }
+    return result;
+}
+
+export function toFloatArray(v) {
+    const result = new Float32Array(v.size());
+    for (let i = 0, n = v.size(); i < n; i++) {
+        result[i] = v.get(i);
+    }
+    return result;
+}
+
 export function variance(v, mean) {
     const size = v.size();
     if (size <= 1) {
@@ -264,29 +282,38 @@ export function variance(v, mean) {
     return ss / n;
 }
 
+
 export function stats(v) {
-    let min = Number.MAX_VALUE;
-    let max = -Number.MAX_VALUE;
-    let mean = 0;
-    let numExpressed = 0;
+
     if (v.size() === 0) {
         return {
-            'min': Number.NaN, 'max': Number.NaN, 'sum': Number.NaN, 'mean': Number.NaN, 'numExpressed': Number.NaN,
+            min: Number.NaN,
+            max: Number.NaN,
+            sum: Number.NaN,
+            mean: Number.NaN,
+            numExpressed: Number.NaN,
+            logSum: Number.NaN
         };
     }
+    let min = Number.MAX_VALUE;
+    let max = -Number.MAX_VALUE;
+    let sum = 0;
+    let numExpressed = 0;
+    let logSum = 0;
     for (let i = 0, size = v.size(); i < size; i++) {
         const value = v.get(i);
         min = value < min ? value : min;
         max = value > max ? value : max;
-        mean += value;
+        sum += value;
+        logSum += Math.expm1(value);
         if (value !== 0) {
             numExpressed++;
         }
     }
-    let sum = mean;
-    mean = mean / v.size();
+
+    const mean = sum / v.size();
     return {
-        'min': min, 'max': max, 'sum': sum, 'mean': mean, 'numExpressed': numExpressed,
+        min: min, max: max, sum: sum, mean: mean, numExpressed: numExpressed, n: v.size(), logSum: logSum
     };
 }
 
