@@ -1,7 +1,7 @@
 import {scaleOrdinal} from 'd3-scale';
 import {schemeCategory10, schemePaired} from 'd3-scale-chromatic';
 import {saveAs} from 'file-saver';
-import {find, findIndex, isEqual} from 'lodash';
+import {find, findIndex, isArray, isEqual} from 'lodash';
 import OpenSeadragon from 'openseadragon';
 import isPlainObject from 'react-redux/lib/utils/isPlainObject';
 import CustomError from '../CustomError';
@@ -11,6 +11,7 @@ import {updateJob} from '../JobResultsPanel';
 import {createCategoryToStats} from '../MetaEmbedding';
 import {RestDataset} from '../RestDataset';
 import {RestServerApi} from '../RestServerApi';
+import {StaticServerApi} from '../StaticServerApi';
 
 import {getPositions} from '../ThreeUtil';
 import {
@@ -30,8 +31,7 @@ import {
     updateTraceColors
 } from '../util';
 
-// export const API = 'http://localhost:5000/api';
-export const API = 'api';
+export const API = process.env.REACT_APP_API_URL || 'api';
 
 const authScopes = [
     'email',
@@ -166,7 +166,16 @@ export function initGapi() {
         }
 
         window.setTimeout(loadingAppProgress, 500);
-
+        if (process.env.REACT_APP_STATIC === 'true') {
+            const serverInfo = {clientId: '', dynamic: false};
+            serverInfo.api = new StaticServerApi();
+            dispatch(setServerInfo(serverInfo));
+            dispatch(_setLoadingApp({loading: false}));
+            dispatch(listDatasets()).then(() => {
+                dispatch(_loadSavedView());
+            });
+            return Promise.resolve();
+        }
         return fetch(API + '/server').then(result => result.json()).then(serverInfo => {
             serverInfo.api = new RestServerApi();
             if (serverInfo.clientId == null) {
@@ -176,8 +185,7 @@ export function initGapi() {
                 serverInfo.dynamic = true;
             }
             dispatch(setServerInfo(serverInfo));
-            if (serverInfo.clientId === '') { // no login required
-
+            if (serverInfo.clientId === '' || serverInfo.clientId == null) { // no login required
 
                 dispatch(_setLoadingApp({loading: false}));
                 dispatch(_setEmail(serverInfo.mode === 'server' ? '' : null));
@@ -188,7 +196,6 @@ export function initGapi() {
                     dispatch(_loadSavedView());
                 });
 
-
             } else {
                 console.log((new Date().getTime() - startTime) / 1000 + " startup time");
                 let script = document.createElement('script');
@@ -913,30 +920,54 @@ export function setServerInfo(payload) {
     return {type: SET_SERVER_INFO, payload: payload};
 }
 
-function loadDefaultDatasetEmbedding() {
+function loadDefaultDatasetView() {
     return function (dispatch, getState) {
         const dataset = getState().dataset;
         const embeddingNames = dataset.embeddings.map(e => e.name);
-        let names = ['tissue_hires', 'fle', 'umap', 'tsne'];
-        let embeddingNames2Priority = {};
-        embeddingNames.forEach(name => {
-            const nameLower = name.toLowerCase();
-            for (let i = 0; i < names.length; i++) {
-                if (nameLower.indexOf(names[i]) !== -1) {
-                    embeddingNames2Priority[name] = i;
-                    break;
+        if (embeddingNames.length > 0) {
+            let embeddingPriorities = ['tissue_hires', 'fle', 'umap', 'tsne'];
+            let embeddingName = null;
+            for (let priorityIndex = 0; priorityIndex < embeddingPriorities.length && embeddingName == null; priorityIndex++) {
+                for (let i = 0; i < embeddingNames.length; i++) {
+                    if (embeddingNames[i].toLowerCase().indexOf(embeddingPriorities[priorityIndex]) !== -1) {
+                        embeddingName = embeddingNames[i];
+                        break;
+                    }
                 }
             }
-        });
-        embeddingNames.sort((a, b) => {
-            a = embeddingNames2Priority[a] || Number.MAX_VALUE;
-            b = embeddingNames2Priority[b] || Number.MAX_VALUE;
-            return a - b;
-        });
 
-        if (embeddingNames.length > 0) {
-            dispatch(setSelectedEmbedding([dataset.embeddings[dataset.embeddings.map(e => e.name).indexOf(embeddingNames[0])]]));
+            if (embeddingName == null) {
+                embeddingName = embeddingNames[0];
+            }
+            const selectedEmbedding = dataset.embeddings[dataset.embeddings.map(e => e.name).indexOf(embeddingName)];
+            let obsCat = null;
+            if (dataset.markers_read_only != null && dataset.markers_read_only.length > 0) {
+                let category = dataset.markers_read_only[0].category;
+                const suffix = ' (rank_genes_groups)';
+                if (category.endsWith(suffix)) {
+                    category = category.substring(0, category.length - suffix.length);
+                }
+                if (dataset.obsCat.indexOf(category) !== -1) {
+                    obsCat = category;
+                }
+            }
+            if (obsCat == null) {
+                let catPriorities = ['leiden', 'louvain', 'seurat_clusters', 'clusters'];
+                for (let priorityIndex = 0; priorityIndex < catPriorities.length && obsCat == null; priorityIndex++) {
+                    for (let i = 0; i < dataset.obsCat.length; i++) {
+                        if (dataset.obsCat[i].toLowerCase().indexOf(catPriorities[priorityIndex]) !== -1) {
+                            obsCat = dataset.obsCat[i];
+                            break;
+                        }
+                    }
+                }
+            }
+            if (obsCat != null) {
+                dispatch(setSearchTokensDirectly([{value: obsCat, type: FEATURE_TYPE.OBS_CAT}]));
+            }
+            dispatch(setSelectedEmbedding([selectedEmbedding]));
         }
+
     };
 }
 
@@ -1160,7 +1191,6 @@ export function deleteDataset(payload) {
             dispatch(_setDataset(null));
             dispatch(_deleteDataset({id: payload.dataset.id}));
             dispatch(setDialog(null));
-
             dispatch(setMessage('Dataset deleted'));
         }).finally(() => {
             dispatch(_setLoading(false));
@@ -1461,7 +1491,7 @@ export function setDataset(id, loadDefaultView = true, setLoading = true) {
             if (savedDatasetState) {
                 dispatch(restoreSavedView(savedDatasetState));
             } else if (loadDefaultView) {
-                dispatch(loadDefaultDatasetEmbedding());
+                dispatch(loadDefaultDatasetView());
             }
         }
 
@@ -1598,7 +1628,6 @@ function _updateCharts(onError) {
             return;
         }
         dispatch(_setLoading(true));
-
         const searchTokens = splitSearchTokens(state.searchTokens);
         addFeatureSetsToX(getFeatureSets(state.markers, searchTokens.featureSets), searchTokens.X);
         let distribution = (searchTokens.X.length > 0 || searchTokens.featureSets.length > 0) && searchTokens.obsCat.length > 0;
@@ -1887,6 +1916,8 @@ function updateEmbeddingData(state, features) {
         const x = traceType !== TRACE_TYPE_META_IMAGE ? coordinates[embedding.name + '_1'] : null;
         const y = traceType !== TRACE_TYPE_META_IMAGE ? coordinates[embedding.name + '_2'] : null;
         const z = traceType !== TRACE_TYPE_META_IMAGE ? coordinates[embedding.name + '_3'] : null;
+
+
         const bins = isBinned ? coordinates.bins : null;
         features.forEach(feature => {
             const featurePlusEmbeddingKey = feature + '_' + embeddingKey;
@@ -1952,11 +1983,9 @@ function updateEmbeddingData(state, features) {
                     //     traceSummary.counts = traceSummary.counts.concat([state.dataset.shape[0] - traceSummary.counts[0]]);
                     // }
 
-                    let colors = dataset.colors ? dataset.colors[feature] : null;
-                    if (colors != null && colors.length !== traceUniqueValues.length) {
-                        colors = null;
-                    }
-                    if (colors == null) {
+                    let colorMap = dataset.colors ? dataset.colors[feature] : null;
+                    let colors;
+                    if (colorMap == null) {
                         if (traceUniqueValues.length <= 10) {
                             colors = schemeCategory10;
                         } else if (traceUniqueValues.length <= 12) {
@@ -1966,8 +1995,22 @@ function updateEmbeddingData(state, features) {
                         } else {
                             colors = CATEGORY_20B.concat(CATEGORY_20C);
                         }
+                    } else {
+                        if (isArray(colorMap)) {
+                            colors = colorMap;
+                        } else {
+                            colors = [];
+                            traceUniqueValues.forEach((value, index) => {
+                                let color = colorMap[value];
+                                if (color == null) {
+                                    color = schemeCategory10[index % schemeCategory10.length];
+                                }
+                                colors.push(color);
+                            });
+                        }
                     }
 
+
                     colorScale = scaleOrdinal(colors).domain(traceUniqueValues);
                     colorScale.summary = featureSummary;
                 }
