@@ -5,8 +5,6 @@ import pytest
 
 from cirrocumulus.anndata_dataset import AnndataDataset
 from cirrocumulus.dataset_api import DatasetAPI
-from cirrocumulus.entity import Entity
-from cirrocumulus.zarr_dataset_backed import ZarrDatasetBacked
 
 
 @pytest.fixture(scope='module', autouse=True)
@@ -16,7 +14,7 @@ def test_data():
 
 @pytest.fixture(scope='module', autouse=True, params=['small', 'large'])
 def measures(request):
-    return ['TNFRSF4', 'DSCR3', 'SUMO3'] if request.param == 'small' else list(
+    return ['DSCR3', 'TNFRSF4', 'SUMO3'] if request.param == 'small' else list(
         anndata.read('test-data/pbmc3k_no_raw.h5ad').var.index[0:20])
 
 
@@ -54,15 +52,15 @@ def h5_dataset_force_sparse(request):
 def dataset_api(h5_dataset_backed, h5_dataset_force_sparse):
     dataset_api = DatasetAPI()
     dataset_api.add(AnndataDataset(backed=h5_dataset_backed, force_sparse=h5_dataset_force_sparse, extensions=['h5ad']))
-    dataset_api.add(ZarrDatasetBacked())
     return dataset_api
 
 
 @pytest.fixture(scope='module', params=['test-data/pbmc3k_no_raw.h5ad'])
 def input_dataset(request):
-    meta = {'name': os.path.splitext(os.path.basename(request.param))[0], 'url': request.param}
+    meta = {'name': os.path.splitext(os.path.basename(request.param))[0], 'url': request.param, 'id': request.param}
     if request.param.endswith('.json'):
         import json
         with open(request.param, 'rt') as f:
             meta.update(json.load(f))
-    return Entity(request.param, meta)
+
+    return meta
